@@ -1,5 +1,5 @@
 /*!
- * CSSPlugin 3.5.1
+ * CSSPlugin 3.3.4
  * https://greensock.com
  *
  * Copyright 2008-2020, GreenSock. All rights reserved.
@@ -115,7 +115,7 @@ _renderRoundedCSSProp = function _renderRoundedCSSProp(ratio, data) {
     };
     _tempDivStyler = _createElement("div");
     _transformProp = _checkPropPrefix(_transformProp);
-    _transformOriginProp = _transformProp + "Origin";
+    _transformOriginProp = _checkPropPrefix(_transformOriginProp);
     _tempDiv.style.cssText = "border-width:0;line-height:0;position:absolute;padding:0"; //make sure to override certain properties that may contaminate measurements, in case the user has overreaching style sheets.
 
     _supports3D = !!_checkPropPrefix("perspective");
@@ -194,7 +194,7 @@ _removeProperty = function _removeProperty(target, property) {
   if (property) {
     var style = target.style;
 
-    if (property in _transformProps && property !== _transformOriginProp) {
+    if (property in _transformProps) {
       property = _transformProp;
     }
 
@@ -290,7 +290,10 @@ _convertToUnit = function _convertToUnit(target, property, value, unit) {
 },
     _get = function _get(target, property, unit, uncache) {
   var value;
-  _pluginInitted || _initCore();
+
+  if (!_pluginInitted) {
+    _initCore();
+  }
 
   if (property in _propertyAliases && property !== "transform") {
     property = _propertyAliases[property];
@@ -323,8 +326,6 @@ _convertToUnit = function _convertToUnit(target, property, value, unit) {
     if (s && s !== start) {
       prop = p;
       start = s;
-    } else if (prop === "borderColor") {
-      start = _getComputedProperty(target, "borderTopColor"); // Firefox bug: always reports "borderColor" as "", so we must fall back to borderTopColor. See https://greensock.com/forums/topic/24583-how-to-return-colors-that-i-had-after-reverse/
     }
   }
 
@@ -1200,7 +1201,10 @@ export var CSSPlugin = {
         cache,
         smooth,
         hasPriority;
-    _pluginInitted || _initCore();
+
+    if (!_pluginInitted) {
+      _initCore();
+    }
 
     for (p in vars) {
       if (p === "autoRound") {
@@ -1233,7 +1237,7 @@ export var CSSPlugin = {
       } else if (p.substr(0, 2) === "--") {
         //CSS variable
         this.add(style, "setProperty", getComputedStyle(target).getPropertyValue(p) + "", endValue + "", index, targets, 0, 0, p);
-      } else if (type !== "undefined") {
+      } else {
         startValue = _get(target, p);
         startNum = parseFloat(startValue);
         relative = type === "string" && endValue.charAt(1) === "=" ? +(endValue.charAt(0) + "1") : 0;
@@ -1257,7 +1261,10 @@ export var CSSPlugin = {
 
           if (p !== "scale" && p !== "transform") {
             p = _propertyAliases[p];
-            ~p.indexOf(",") && (p = p.split(",")[0]);
+
+            if (~p.indexOf(",")) {
+              p = p.split(",")[0];
+            }
           }
         }
 
@@ -1286,7 +1293,9 @@ export var CSSPlugin = {
             } else {
               endUnit = parseFloat(endValue.split(" ")[2]) || 0; //handle the zOrigin separately!
 
-              endUnit !== cache.zOrigin && _addNonTweeningPT(this, cache, "zOrigin", cache.zOrigin, endUnit);
+              if (endUnit !== cache.zOrigin) {
+                _addNonTweeningPT(this, cache, "zOrigin", cache.zOrigin, endUnit);
+              }
 
               _addNonTweeningPT(this, style, p, _firstTwoOnly(startValue), _firstTwoOnly(endValue));
             }
@@ -1320,8 +1329,12 @@ export var CSSPlugin = {
           startUnit = (startValue + "").substr((startNum + "").length);
           endNum || (endNum = 0); // protect against NaN
 
-          endUnit = getUnit(endValue) || (p in _config.units ? _config.units[p] : startUnit);
-          startUnit !== endUnit && (startNum = _convertToUnit(target, p, startValue, endUnit));
+          endUnit = (endValue + "").substr((endNum + "").length) || (p in _config.units ? _config.units[p] : startUnit);
+
+          if (startUnit !== endUnit) {
+            startNum = _convertToUnit(target, p, startValue, endUnit);
+          }
+
           this._pt = new PropTween(this._pt, isTransformRelated ? cache : style, p, startNum, relative ? relative * endNum : endNum - startNum, endUnit === "px" && vars.autoRound !== false && !isTransformRelated ? _renderRoundedCSSProp : _renderCSSProp);
           this._pt.u = endUnit || 0;
 
@@ -1347,7 +1360,9 @@ export var CSSPlugin = {
       }
     }
 
-    hasPriority && _sortPropTweensByPriority(this);
+    if (hasPriority) {
+      _sortPropTweensByPriority(this);
+    }
   },
   get: _get,
   aliases: _propertyAliases,
